==> kio-5.69.0-1-x86_64.pkg.tar.zst: usr/include/KF5/KIOFileWidgets/kiofilewidgets_export.h <==

#ifndef KIOFILEWIDGETS_EXPORT_H
#define KIOFILEWIDGETS_EXPORT_H

#ifdef KIOFILEWIDGETS_STATIC_DEFINE
#  define KIOFILEWIDGETS_EXPORT
#  define KIOFILEWIDGETS_NO_EXPORT
#else
#  ifndef KIOFILEWIDGETS_EXPORT
#    ifdef KF5KIOFileWidgets_EXPORTS
        /* We are building this library */
#      define KIOFILEWIDGETS_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KIOFILEWIDGETS_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KIOFILEWIDGETS_NO_EXPORT
#    define KIOFILEWIDGETS_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KIOFILEWIDGETS_DECL_DEPRECATED
#  define KIOFILEWIDGETS_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KIOFILEWIDGETS_DECL_DEPRECATED_EXPORT
#  define KIOFILEWIDGETS_DECL_DEPRECATED_EXPORT KIOFILEWIDGETS_EXPORT KIOFILEWIDGETS_DECL_DEPRECATED
#endif

#ifndef KIOFILEWIDGETS_DECL_DEPRECATED_NO_EXPORT
#  define KIOFILEWIDGETS_DECL_DEPRECATED_NO_EXPORT KIOFILEWIDGETS_NO_EXPORT KIOFILEWIDGETS_DECL_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KIOFILEWIDGETS_NO_DEPRECATED
#    define KIOFILEWIDGETS_NO_DEPRECATED
#  endif
#endif

#define KIOFILEWIDGETS_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))

/* Take any defaults from group settings */
#if !defined(KIOFILEWIDGETS_NO_DEPRECATED) && !defined(KIOFILEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define KIOFILEWIDGETS_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define KIOFILEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(KIOFILEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define KIOFILEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(KIOFILEWIDGETS_NO_DEPRECATED_WARNINGS) && !defined(KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define KIOFILEWIDGETS_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(KIOFILEWIDGETS_NO_DEPRECATED)
#  undef KIOFILEWIDGETS_DEPRECATED
#  define KIOFILEWIDGETS_DEPRECATED_EXPORT KIOFILEWIDGETS_EXPORT
#  define KIOFILEWIDGETS_DEPRECATED_NO_EXPORT KIOFILEWIDGETS_NO_EXPORT
#elif defined(KIOFILEWIDGETS_NO_DEPRECATED_WARNINGS)
#  define KIOFILEWIDGETS_DEPRECATED
#  define KIOFILEWIDGETS_DEPRECATED_EXPORT KIOFILEWIDGETS_EXPORT
#  define KIOFILEWIDGETS_DEPRECATED_NO_EXPORT KIOFILEWIDGETS_NO_EXPORT
#else
#  define KIOFILEWIDGETS_DEPRECATED KIOFILEWIDGETS_DECL_DEPRECATED
#  define KIOFILEWIDGETS_DEPRECATED_EXPORT KIOFILEWIDGETS_DECL_DEPRECATED_EXPORT
#  define KIOFILEWIDGETS_DEPRECATED_NO_EXPORT KIOFILEWIDGETS_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KIOFILEWIDGETS_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KIOFILEWIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KIOFILEWIDGETS_NO_DEPRECATED
#  define KIOFILEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54500
#endif
#ifdef KIOFILEWIDGETS_NO_DEPRECATED_WARNINGS
#  define KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE
#  ifdef KIOFILEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE KIOFILEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE 0x54500
#  endif
#endif

#ifndef KIOFILEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KIOFILEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef KIOFILEWIDGETS_DEPRECATED
#  define KIOFILEWIDGETS_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KIOFILEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KIOFILEWIDGETS_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#if KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x40300
#  define KIOFILEWIDGETS_DEPRECATED_VERSION_4_3(text) KIOFILEWIDGETS_DECL_DEPRECATED_TEXT(text)
#else
#  define KIOFILEWIDGETS_DEPRECATED_VERSION_4_3(text)
#endif

#if KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x40500
#  define KIOFILEWIDGETS_DEPRECATED_VERSION_4_5(text) KIOFILEWIDGETS_DECL_DEPRECATED_TEXT(text)
#else
#  define KIOFILEWIDGETS_DEPRECATED_VERSION_4_5(text)
#endif

#if KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x50000
#  define KIOFILEWIDGETS_DEPRECATED_VERSION_5_0(text) KIOFILEWIDGETS_DECL_DEPRECATED_TEXT(text)
#else
#  define KIOFILEWIDGETS_DEPRECATED_VERSION_5_0(text)
#endif

#if KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x52100
#  define KIOFILEWIDGETS_DEPRECATED_VERSION_5_33(text) KIOFILEWIDGETS_DECL_DEPRECATED_TEXT(text)
#else
#  define KIOFILEWIDGETS_DEPRECATED_VERSION_5_33(text)
#endif

#if KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x54200
#  define KIOFILEWIDGETS_DEPRECATED_VERSION_5_66(text) KIOFILEWIDGETS_DECL_DEPRECATED_TEXT(text)
#else
#  define KIOFILEWIDGETS_DEPRECATED_VERSION_5_66(text)
#endif
#define KIOFILEWIDGETS_DEPRECATED_VERSION_4(minor, text)      KIOFILEWIDGETS_DEPRECATED_VERSION_4_##minor(text)
#define KIOFILEWIDGETS_DEPRECATED_VERSION_5(minor, text)      KIOFILEWIDGETS_DEPRECATED_VERSION_5_##minor(text)
#define KIOFILEWIDGETS_DEPRECATED_VERSION(major, minor, text) KIOFILEWIDGETS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)

#endif /* KIOFILEWIDGETS_EXPORT_H */

==> kio-5.84.0-1-x86_64.pkg.tar.zst: usr/include/KF5/KIOFileWidgets/kiofilewidgets_export.h <==

#ifndef KIOFILEWIDGETS_EXPORT_H
#define KIOFILEWIDGETS_EXPORT_H

#ifdef KIOFILEWIDGETS_STATIC_DEFINE
#  define KIOFILEWIDGETS_EXPORT
#  define KIOFILEWIDGETS_NO_EXPORT
#else
#  ifndef KIOFILEWIDGETS_EXPORT
#    ifdef KF5KIOFileWidgets_EXPORTS
        /* We are building this library */
#      define KIOFILEWIDGETS_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KIOFILEWIDGETS_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KIOFILEWIDGETS_NO_EXPORT
#    define KIOFILEWIDGETS_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KIOFILEWIDGETS_DECL_DEPRECATED
#  define KIOFILEWIDGETS_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KIOFILEWIDGETS_DECL_DEPRECATED_EXPORT
#  define KIOFILEWIDGETS_DECL_DEPRECATED_EXPORT KIOFILEWIDGETS_EXPORT KIOFILEWIDGETS_DECL_DEPRECATED
#endif

#ifndef KIOFILEWIDGETS_DECL_DEPRECATED_NO_EXPORT
#  define KIOFILEWIDGETS_DECL_DEPRECATED_NO_EXPORT KIOFILEWIDGETS_NO_EXPORT KIOFILEWIDGETS_DECL_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KIOFILEWIDGETS_NO_DEPRECATED
#    define KIOFILEWIDGETS_NO_DEPRECATED
#  endif
#endif

#define KIOFILEWIDGETS_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))

/* Take any defaults from group settings */
#if !defined(KIOFILEWIDGETS_NO_DEPRECATED) && !defined(KIOFILEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define KIOFILEWIDGETS_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define KIOFILEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(KIOFILEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define KIOFILEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(KIOFILEWIDGETS_NO_DEPRECATED_WARNINGS) && !defined(KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define KIOFILEWIDGETS_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(KIOFILEWIDGETS_NO_DEPRECATED)
#  undef KIOFILEWIDGETS_DEPRECATED
#  define KIOFILEWIDGETS_DEPRECATED_EXPORT KIOFILEWIDGETS_EXPORT
#  define KIOFILEWIDGETS_DEPRECATED_NO_EXPORT KIOFILEWIDGETS_NO_EXPORT
#elif defined(KIOFILEWIDGETS_NO_DEPRECATED_WARNINGS)
#  define KIOFILEWIDGETS_DEPRECATED
#  define KIOFILEWIDGETS_DEPRECATED_EXPORT KIOFILEWIDGETS_EXPORT
#  define KIOFILEWIDGETS_DEPRECATED_NO_EXPORT KIOFILEWIDGETS_NO_EXPORT
#else
#  define KIOFILEWIDGETS_DEPRECATED KIOFILEWIDGETS_DECL_DEPRECATED
#  define KIOFILEWIDGETS_DEPRECATED_EXPORT KIOFILEWIDGETS_DECL_DEPRECATED_EXPORT
#  define KIOFILEWIDGETS_DEPRECATED_NO_EXPORT KIOFILEWIDGETS_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KIOFILEWIDGETS_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KIOFILEWIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KIOFILEWIDGETS_NO_DEPRECATED
#  define KIOFILEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55400
#endif
#ifdef KIOFILEWIDGETS_NO_DEPRECATED_WARNINGS
#  define KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE
#  ifdef KIOFILEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE KIOFILEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE 0x55400
#  endif
#endif

#ifndef KIOFILEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KIOFILEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef KIOFILEWIDGETS_DEPRECATED
#  define KIOFILEWIDGETS_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KIOFILEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KIOFILEWIDGETS_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#if KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x40300
#  define KIOFILEWIDGETS_DEPRECATED_VERSION_4_3(text) KIOFILEWIDGETS_DECL_DEPRECATED_TEXT(text)
#else
#  define KIOFILEWIDGETS_DEPRECATED_VERSION_4_3(text)
#endif

#if KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x40500
#  define KIOFILEWIDGETS_DEPRECATED_VERSION_4_5(text) KIOFILEWIDGETS_DECL_DEPRECATED_TEXT(text)
#else
#  define KIOFILEWIDGETS_DEPRECATED_VERSION_4_5(text)
#endif

#if KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x50000
#  define KIOFILEWIDGETS_DEPRECATED_VERSION_5_0(text) KIOFILEWIDGETS_DECL_DEPRECATED_TEXT(text)
#else
#  define KIOFILEWIDGETS_DEPRECATED_VERSION_5_0(text)
#endif

#if KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x52100
#  define KIOFILEWIDGETS_DEPRECATED_VERSION_5_33(text) KIOFILEWIDGETS_DECL_DEPRECATED_TEXT(text)
#else
#  define KIOFILEWIDGETS_DEPRECATED_VERSION_5_33(text)
#endif

#if KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x54200
#  define KIOFILEWIDGETS_DEPRECATED_VERSION_5_66(text) KIOFILEWIDGETS_DECL_DEPRECATED_TEXT(text)
#else
#  define KIOFILEWIDGETS_DEPRECATED_VERSION_5_66(text)
#endif

#if KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x54600
#  define KIOFILEWIDGETS_DEPRECATED_VERSION_5_70(text) KIOFILEWIDGETS_DECL_DEPRECATED_TEXT(text)
#else
#  define KIOFILEWIDGETS_DEPRECATED_VERSION_5_70(text)
#endif

#if KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x54c00
#  define KIOFILEWIDGETS_DEPRECATED_VERSION_5_76(text) KIOFILEWIDGETS_DECL_DEPRECATED_TEXT(text)
#else
#  define KIOFILEWIDGETS_DEPRECATED_VERSION_5_76(text)
#endif

#if KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x54e00
#  define KIOFILEWIDGETS_DEPRECATED_VERSION_5_78(text) KIOFILEWIDGETS_DECL_DEPRECATED_TEXT(text)
#else
#  define KIOFILEWIDGETS_DEPRECATED_VERSION_5_78(text)
#endif
#define KIOFILEWIDGETS_DEPRECATED_VERSION_4(minor, text)      KIOFILEWIDGETS_DEPRECATED_VERSION_4_##minor(text)
#define KIOFILEWIDGETS_DEPRECATED_VERSION_5(minor, text)      KIOFILEWIDGETS_DEPRECATED_VERSION_5_##minor(text)
#define KIOFILEWIDGETS_DEPRECATED_VERSION(major, minor, text) KIOFILEWIDGETS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
#define KIOFILEWIDGETS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KIOFILEWIDGETS_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
#  define KIOFILEWIDGETS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KIOFILEWIDGETS_DEPRECATED_VERSION(major, minor, text)
#  define KIOFILEWIDGETS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KIOFILEWIDGETS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#else
#  define KIOFILEWIDGETS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
#  define KIOFILEWIDGETS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#endif

#endif /* KIOFILEWIDGETS_EXPORT_H */


#ifndef ECM_GENERATEEXPORTHEADER_KIOFILEWIDGETS_EXPORT_H
#define ECM_GENERATEEXPORTHEADER_KIOFILEWIDGETS_EXPORT_H


#define KIOFILEWIDGETS_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))

/* Take any defaults from group settings */
#if !defined(KIOFILEWIDGETS_NO_DEPRECATED) && !defined(KIOFILEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define KIOFILEWIDGETS_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define KIOFILEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(KIOFILEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define KIOFILEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(KIOFILEWIDGETS_NO_DEPRECATED_WARNINGS) && !defined(KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define KIOFILEWIDGETS_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(KIOFILEWIDGETS_NO_DEPRECATED)
#  undef KIOFILEWIDGETS_DEPRECATED
#  define KIOFILEWIDGETS_DEPRECATED_EXPORT KIOFILEWIDGETS_EXPORT
#  define KIOFILEWIDGETS_DEPRECATED_NO_EXPORT KIOFILEWIDGETS_NO_EXPORT
#elif defined(KIOFILEWIDGETS_NO_DEPRECATED_WARNINGS)
#  define KIOFILEWIDGETS_DEPRECATED
#  define KIOFILEWIDGETS_DEPRECATED_EXPORT KIOFILEWIDGETS_EXPORT
#  define KIOFILEWIDGETS_DEPRECATED_NO_EXPORT KIOFILEWIDGETS_NO_EXPORT
#else
#  define KIOFILEWIDGETS_DEPRECATED KIOFILEWIDGETS_DECL_DEPRECATED
#  define KIOFILEWIDGETS_DEPRECATED_EXPORT KIOFILEWIDGETS_DECL_DEPRECATED_EXPORT
#  define KIOFILEWIDGETS_DEPRECATED_NO_EXPORT KIOFILEWIDGETS_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KIOFILEWIDGETS_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KIOFILEWIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KIOFILEWIDGETS_NO_DEPRECATED
#  define KIOFILEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55400
#endif
#ifdef KIOFILEWIDGETS_NO_DEPRECATED_WARNINGS
#  define KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE
#  ifdef KIOFILEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE KIOFILEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE 0x55400
#  endif
#endif

#ifndef KIOFILEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KIOFILEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef KIOFILEWIDGETS_DEPRECATED
#  define KIOFILEWIDGETS_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KIOFILEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KIOFILEWIDGETS_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#if KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x40300
#  define KIOFILEWIDGETS_DEPRECATED_VERSION_4_3(text) KIOFILEWIDGETS_DECL_DEPRECATED_TEXT(text)
#else
#  define KIOFILEWIDGETS_DEPRECATED_VERSION_4_3(text)
#endif

#if KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x40500
#  define KIOFILEWIDGETS_DEPRECATED_VERSION_4_5(text) KIOFILEWIDGETS_DECL_DEPRECATED_TEXT(text)
#else
#  define KIOFILEWIDGETS_DEPRECATED_VERSION_4_5(text)
#endif

#if KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x50000
#  define KIOFILEWIDGETS_DEPRECATED_VERSION_5_0(text) KIOFILEWIDGETS_DECL_DEPRECATED_TEXT(text)
#else
#  define KIOFILEWIDGETS_DEPRECATED_VERSION_5_0(text)
#endif

#if KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x52100
#  define KIOFILEWIDGETS_DEPRECATED_VERSION_5_33(text) KIOFILEWIDGETS_DECL_DEPRECATED_TEXT(text)
#else
#  define KIOFILEWIDGETS_DEPRECATED_VERSION_5_33(text)
#endif

#if KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x54200
#  define KIOFILEWIDGETS_DEPRECATED_VERSION_5_66(text) KIOFILEWIDGETS_DECL_DEPRECATED_TEXT(text)
#else
#  define KIOFILEWIDGETS_DEPRECATED_VERSION_5_66(text)
#endif

#if KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x54600
#  define KIOFILEWIDGETS_DEPRECATED_VERSION_5_70(text) KIOFILEWIDGETS_DECL_DEPRECATED_TEXT(text)
#else
#  define KIOFILEWIDGETS_DEPRECATED_VERSION_5_70(text)
#endif

#if KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x54c00
#  define KIOFILEWIDGETS_DEPRECATED_VERSION_5_76(text) KIOFILEWIDGETS_DECL_DEPRECATED_TEXT(text)
#else
#  define KIOFILEWIDGETS_DEPRECATED_VERSION_5_76(text)
#endif

#if KIOFILEWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x54e00
#  define KIOFILEWIDGETS_DEPRECATED_VERSION_5_78(text) KIOFILEWIDGETS_DECL_DEPRECATED_TEXT(text)
#else
#  define KIOFILEWIDGETS_DEPRECATED_VERSION_5_78(text)
#endif
#define KIOFILEWIDGETS_DEPRECATED_VERSION_4(minor, text)      KIOFILEWIDGETS_DEPRECATED_VERSION_4_##minor(text)
#define KIOFILEWIDGETS_DEPRECATED_VERSION_5(minor, text)      KIOFILEWIDGETS_DEPRECATED_VERSION_5_##minor(text)
#define KIOFILEWIDGETS_DEPRECATED_VERSION(major, minor, text) KIOFILEWIDGETS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
#define KIOFILEWIDGETS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KIOFILEWIDGETS_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
#  define KIOFILEWIDGETS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KIOFILEWIDGETS_DEPRECATED_VERSION(major, minor, text)
#  define KIOFILEWIDGETS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KIOFILEWIDGETS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#else
#  define KIOFILEWIDGETS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
#  define KIOFILEWIDGETS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#endif


#endif /* ECM_GENERATEEXPORTHEADER_KIOFILEWIDGETS_EXPORT_H */
